@@ -45,6 +45,8 @@ AAptInterface::AAptInterface(QObject* parent = 0) : QObject(parent)
 	iLastListUpdate.setTime_t(0);
 	iLastDpkgUpdate.setTime_t(0);
 
+	iDataReadBuffer = new char[KDataReadBufferSize];
+
 	iProcAptGetUpdate = new QProcess(this);
 	iProcAptGetSimulate = new QProcess(this);
 	iProcAptGetInstall = new QProcess(this);
@@ -103,6 +105,8 @@ AAptInterface::~AAptInterface()
 		iProcAptGetInstall->kill();
 	if( iProcAptGetClean->state() != QProcess::NotRunning )
 		iProcAptGetClean->kill();
+
+	delete iDataReadBuffer;
 }
 
 void AAptInterface::addQueuedOperation(interfaceMode mode_)
@@ -1299,6 +1303,7 @@ void AAptInterface::startPkgListRead()
 	}
 
 	readBlacklist();
+	readPinnedPackages();
 
 	communicateStatusToUi(true, "Operation finished", "Package data read");
 	iCanCancel = false;
@@ -1314,17 +1319,15 @@ Package* AAptInterface::ReadNextPackage(QFile& f, quint64& currentreaddata)
 	bool pkgready = false;
 
 	// this is faster than directly reading to QByteArray...
-	char* data = new char[25000];
 	QByteArray line;
 	while( !pkgready && !f.atEnd() ) {
-		f.readLine(data,25000);
-		line = data;
+		f.readLine(iDataReadBuffer,KDataReadBufferSize);
+		line = iDataReadBuffer;
 		currentreaddata += line.size();
 		if( processPackageDataLine(pkg,line) ) {
 			pkgready = true;
 		}
 	}
-	delete data;
 
 	if( !pkg->name().isEmpty() && pkg->isInstalled() ) {
 		QFileInfo f( KDpkgInfoDir + "/" + pkg->name() + ".list" );
@@ -1859,6 +1862,37 @@ bool AAptInterface::dateCacheExists()
 	return f.exists();
 }
 
+void AAptInterface::readPinnedPackages()
+{
+	QFile f(KAptPreferencesFile);
+	if( !f.exists() )
+		return;
+
+	if( f.open(QIODevice::ReadOnly | QIODevice::Text ) )
+	{
+		qDebug() << "apt preferences exist: reading pinned packages";
+		int pinned_packages = 0;
+		while( !f.atEnd() )
+		{
+			QString line = f.readLine().trimmed();
+			if( line.startsWith("Package:") ) {
+				pinned_packages++;
+				QString pkg = line.mid(8).trimmed();
+				Package* pkg_i = iPackagesInstalled.value(pkg,0);
+				if( pkg_i ) {
+					pkg_i->setPinned(true);
+				}
+				Package* pkg_a = iPackagesAvailable.value(pkg,0);
+				if( pkg_a ) {
+					pkg_a->setPinned(true);
+				}
+			}
+		}
+		f.close();
+		qDebug() << "read" << pinned_packages << "pinned packages";
+	}
+}
+
 bool AAptInterface::loadInstallFiles(QStringList files_)
 {
 	qDebug() << files_;
