@@ -351,6 +351,8 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 		if( inst.count()>0 )
 			pkglist += QString("Total download size: %L1 kB<br>").arg(total_dl_size);
 		bool mismatch = false;
+		bool warn_system_package_remove = false;
+		bool warn_system_package_install = false;
 
 		if( remv.count()>0 ) {
 			pkglist += "<br><b><u>REMOVE:</u></b><br><font size=\"-1\">";
@@ -362,6 +364,11 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 					pkglist += "<font color=\"red\">***UNKNOWN***</font>";
 					mismatch = true;
 				}
+#ifdef Q_WS_MAEMO_5
+				if( pkg && pkg->maemoDisplayName()=="Maemo 5" ) {
+					warn_system_package_remove = true;
+				}
+#endif
 				if( remvver.count()>i ) {
 					pkglist += " " + remvver.at(i);
 					if( pkg && remvver.at(i) != pkg->version() ) {
@@ -393,6 +400,11 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 					pkglist += "<font color=\"red\">***BLACKLISTED***</font>";
 					installing_blacklisted = true;
 				}
+#ifdef Q_WS_MAEMO_5
+				if( pkg && pkg->maemoDisplayName()=="Maemo 5" ) {
+					warn_system_package_install = true;
+				}
+#endif
 				if( instver.count()>i ) {
 					pkglist += " " + instver.at(i);
 					if( pkg && instver.at(i) != pkg->version() ) {
@@ -420,9 +432,25 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 			b.setText("Warning","Blacklisted package(s) will be installed");
 			b.exec();
 		}
+		if( warn_system_package_remove ) {
+			ConfirmDialog s(false, this);
+			s.setText("Warning","You are about to remove a critical system package.");
+			s.exec();
+		}
+		if( warn_system_package_install ) {
+			ConfirmDialog s(false, this);
+			s.setText("Warning","You are trying to perform an install/upgrade operation on a critical system package. Doing a system upgrade with " \
+					  "Faster Application Manager has not been tested and it could result in a horrible failure. You have been warned.");
+			s.exec();
+		}
 
 		busyDialog(false);
 		ConfirmDialog d(true, this);
+		if( inst.count()==0 && remv.count()==0 )
+		{
+			pkglist = "None of the packages can be installed";
+			d.disableButton();
+		}
 		d.setText("Confirmation",pkglist);
 		if( d.exec() ) {
 			iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetInstall);
@@ -469,6 +497,10 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 		} else {
 #ifdef Q_WS_MAEMO_5
 			QMaemo5InformationBox::information(0, text, QMaemo5InformationBox::NoTimeout);
+#else
+			ConfirmDialog d(false, this);
+			d.setText(title,msgs.join("<br>"));
+			d.exec();
 #endif
 		}
 
