@@ -55,7 +55,6 @@ public:
 	void GdkEventIconThemeReload();
 	void notifyDialog(QString title, QString msg);
 	bool confirmDialog(QString title, QString msg);
-	void resetIdlingTime() { iIdlingSince = QDateTime::currentDateTime(); }
 	void setNextOperation(nextOperation op_) { iNextOperation=op_; }
 
 public slots:
@@ -84,8 +83,6 @@ private:
 	nextOperation iNextOperation;
 	Phonon::MediaObject* iMediaObject;
 
-	QDateTime iIdlingSince;
-
 private slots:
 	void on_actionLoad_file_triggered();
 	void on_actionOptions_triggered();
