@@ -27,7 +27,7 @@
 Package::Package(QByteArray name_, AAptInterface *apt_):
 		iAptInterface(apt_), iName(name_), iIsInstalled(false), iMarkedForOperation(false),
 		iPkgStatus(PkgStatUnknown), iSize(0), iInstalledSize(0), iMarkedOperation(PkgOpNone),
-		iBlacklist(BlacklistSelect::BlacklistNone), iIcon(0)
+		iBlacklist(BlacklistSelect::BlacklistNone), iIcon(0), iPinned(false)
 {
 }
 
@@ -90,7 +90,7 @@ void Package::convertIcon()
 
 bool Package::isUpgradeable()
 {
-	if( iSection=="user/hidden" )
+	if( iSection=="user/hidden" || iPinned )
 		return false;
 
 	if( iIsInstalled )
