@@ -61,6 +61,7 @@ public:
 	inline void appendRecommends(QByteArray line_) { iRecommends << line_.split(','); }
 	inline void appendSuggests(QByteArray line_) { iSuggests << line_.split(','); }
 	inline void appendUpgradeDescription(QByteArray d_) { iUpgradeDescription.append(d_); }
+	inline void setPinned(bool p_) { iPinned=p_; }
 
 	void convertIcon();
 
@@ -97,6 +98,7 @@ public:
 	inline QList<QByteArray> breaks() { return iBreaks; }
 	inline QList<QByteArray> recommends() { return iRecommends; }
 	inline QList<QByteArray> suggests() { return iSuggests; }
+	inline bool isPinned() { return iPinned; }
 
 	QStringList checkConflicts_RichText();
 
@@ -138,6 +140,8 @@ private:
 	QList<QByteArray> iBreaks;
 	QList<QByteArray> iRecommends;
 	QList<QByteArray> iSuggests;
+
+	bool iPinned;
 };
 
 #endif // PACKAGE_H
