@@ -535,7 +535,6 @@ void PackageView::closeEvent(QCloseEvent *event)
 		return;
 	}
 
-#ifdef Q_WS_MAEMO_5
 	if( iAptInterface->numSelectedPackages() == 0 )
 	{		
 		resetWindow();
@@ -552,10 +551,6 @@ void PackageView::closeEvent(QCloseEvent *event)
 			event->ignore();
 		}
 	}
-#else	// for simulator
-	resetWindow();
-	event->accept();
-#endif
 }
 
 void PackageView::changeEvent(QEvent *e)
@@ -664,6 +659,13 @@ void PackageView::on_listWidget_itemClicked(QListWidgetItem* item)
 			op = Package::PkgOpNone;
 	}
 
+	if( pkg->isPinned() && op != Package::PkgOpNone ) {
+		ConfirmDialog d(true, this);
+		d.setText("Warning","Package has been pinned in apt preferences. Operation might not go as expected. Mark anyway?");
+		if( !d.exec() )
+			op = Package::PkgOpNone;
+	}
+
 	pkg->setMarkedForOperation( op );
 	item->setData( UserRoleMarked, (int)op );
 	updateLabel();
