@@ -21,6 +21,7 @@
 #define SETTINGS_H
 
 #include <QtGui>
+#include <QtNetwork>
 
 class AAptInterface;
 class PackageView;
@@ -57,6 +58,8 @@ public:
 
 	QSettings* qsettings() { return iQSettings; }
 
+	static QNetworkProxy createProxyFromString(QString proxystr);
+
 protected:
     void changeEvent(QEvent *e);
 
